import argparse

import get_exif  # type: ignore
import lenses  # type: ignore


def parse_args():
    parser = argparse.ArgumentParser()
    parser.add_argument("-p", "--path", help="Path to recursively search for photos")
    parser.add_argument("-g", "--graphpath", help="Path to save graphs generated by this program")
    return parser.parse_args()


def main():
    args = parse_args()
    photos = get_exif.get_photos(args.path)
    exif = get_exif.get_exif(photos)
    lenses.main(exif, args.graphpath)


if __name__ == '__main__':
    main()
